NullComponent
=============

.. currentmodule:: dash_component_template.template

.. autoclass:: NullComponent
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NullComponent.id
      ~NullComponent.idbase
      ~NullComponent.layout

   .. rubric:: Methods Summary

   .. autosummary::

      ~NullComponent.setup_layout

   .. rubric:: Attributes Documentation

   .. autoattribute:: id
   .. autoattribute:: idbase
   .. autoattribute:: layout

   .. rubric:: Methods Documentation

   .. automethod:: setup_layout
